-- This is BGSoundAlerts Sound Engine
-- Keeps track of what is to play next and when
BGSoundAlerts_SoundQueue = { };
BGSoundAlerts_NextUpdate = 0.3;
BGSoundAlerts_NextKillUpdate = 10;
BGSoundAlerts_ResourcesByUpdate = 1;
local KillSpree_Kills = 0;
local MAX_NUMBER_OF_KILLS = 7;
BGSoundAlerts_ABGameTime = 0;
BGSoundAlerts_EOTSGameTime = 0;

-- Also contains the killing spree sounds functionality

-- Just to keep this file clean, the SoundLengths are in another file

function BGSoundAlerts_AddToQueue(file,unique)
	-- This function will add file to the sound queue to be played
	-- If the sound could not be found in the sound lengths table then just play it
	-- If a unique sound is already in the queue then don't add it (if the sound is already playing then the sound is still added to the queue)
	local i;
	local filefoundlength;
	-- This is a table of soundlengths according to the selected SoundPack. DefaultPack = BGSoundAlerts_DefaultPackDurations
	if (SoundsPack == "DefaultPack") then
		local soundlengthtable = getglobal("BGSoundAlerts_" .. SoundsPack .. "Durations");
		
		-- Is .wav at the end?
		if ((not string.find(file,".wav",string.len(file) - 3)) and (not string.find(file,".WAV",string.len(file) - 3))) then
			-- Nope so add it
			file = file .. ".wav";
		end
		
		if (unique) then
			for i = 1, table.getn(BGSoundAlerts_SoundQueue) do
				if (string.upper(BGSoundAlerts_SoundQueue[i].dir) == string.upper(file)) then
					-- The unique sound was already found in the queue
					return;
				end
			end
		end
		
		for i = 1, table.getn(soundlengthtable) do
			if (string.upper(soundlengthtable[i].dir) == string.upper(file)) then
				filefoundlength = soundlengthtable[i].duration;
			end
		end
		
		if (filefoundlength) then
			local temptable = {
				dir = file,
				length = filefoundlength
				};
			
			-- Insert the sound into the queue
			table.insert(BGSoundAlerts_SoundQueue,temptable);
		else
			-- Not in the sound table so just play it
			PlaySoundFile(file);
		end
	else	
		-- We've got lengths for DefaultPack. If that's not selected just play it
		PlaySoundFile(file);
	end
end

function BGSoundAlerts_AddNumberToQueue(number)

	--- 1032

	-- This function will add a number to the sound queue
	local i, x;
	number = tostring(number);
	if (tonumber(number) < 20 and tonumber(number) > 10) then
		-- It's between 10 and 20
		BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\" .. number .. ".wav");
	else
		-- Play the score numbers
		if (tonumber(string.sub(number,string.len(number) - 1,string.len(number))) > 10 and tonumber(string.sub(number,string.len(number) - 1,string.len(number))) < 20) then
			for i = 1, string.len(number) - 2 do
				local file = "Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\" .. string.sub(number,i,i);
				for x = string.len(number) - 1, i, -1 do
					file = file .. "0";						-- Add 0s
				end
				file = file .. ".wav";
				BGSoundAlerts_AddToQueue(file);
			end
			BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\" .. string.sub(number,string.len(number) - 1,string.len(number)));
		else
			for i = 1, string.len(number) do
				local file = "Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\" .. string.sub(number,i,i);
				for x = string.len(number) - 1, i, -1 do
					file = file .. "0";						-- Add 0s
				end
				file = file .. ".wav";
				BGSoundAlerts_AddToQueue(file);
			end
		end
	end
end
	

function BGSoundAlerts_ClearSoundQueue()
	-- This function will clear all the sound queue
	-- This is used for example in the end of a battle where you no longer need to hear any more announcements
	local i;
	
	for i = table.getn(BGSoundAlerts_SoundQueue), 1 do
		table.remove(BGSoundAlerts_SoundQueue,i);
	end
end

function BGSoundAlerts_PlayNextSound()
	-- This function will play the next sound in the queue and return how long that sound will play
	-- If there is no sound in the queue it will just return 0.3
	if (BGSoundAlerts_SoundInQueue()) then
		local x;
		
		PlaySoundFile(BGSoundAlerts_SoundQueue[1].dir);
		x = BGSoundAlerts_SoundQueue[1].length;
		table.remove(BGSoundAlerts_SoundQueue,1);
		return x;
	else
		return 0.3;
	end
end

function BGSoundAlerts_SoundInQueue()
	-- This function will return 1 if there is a sound in the queue, nil otherwise
	if (table.getn(BGSoundAlerts_SoundQueue) > 0) then
		return 1;
	else
		return nil;
	end
end

function BGSoundAlerts_UpdateSoundEngine(elapsed)
	this.TimeSinceLastUpdate = this.TimeSinceLastUpdate + elapsed; 	
	while (this.TimeSinceLastUpdate > BGSoundAlerts_NextUpdate) do
		this.TimeSinceLastUpdate = this.TimeSinceLastUpdate - BGSoundAlerts_NextUpdate;
		BGSoundAlerts_NextUpdate = BGSoundAlerts_PlayNextSound();
	end
end

function BGSoundAlerts_UpdateABScore(elapsed)
	-- This should happen only in Arathi Basin
	if (GetRealZoneText() == "Arathi Basin" and ABScore == 1) then
		if (not WorldMapFrame:IsVisible()) then
			-- It appears there's a problem when the World Map is open
			this.TimeSinceLastUpdate = this.TimeSinceLastUpdate + elapsed;
		end
		while (this.TimeSinceLastUpdate > ABScoreDelay * 60) do
			BGSoundAlerts_ABGameTime = BGSoundAlerts_ABGameTime + ABScoreDelay;
			if (SoundsPack == "DefaultPack") then
				-- Work out the BG elapsed time
				BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\After.wav");
				BGSoundAlerts_AddNumberToQueue(BGSoundAlerts_ABGameTime);
				BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\MinutesArathiBasin.wav");
				
				local _,AllianceScore = GetWorldStateUIInfo(1);
				local _,HordeScore = GetWorldStateUIInfo(2);
				
				AllianceScore = tonumber(string.sub(AllianceScore,21,string.find(AllianceScore,"/") - 1));
				HordeScore = tonumber(string.sub(HordeScore,21,string.find(HordeScore,"/") - 1));
				
				-- Bases: 4  Resources: 2000/2000
				
				-- See who's in the lead
				if (AllianceScore > HordeScore) then
						BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\Alliance.wav");
				elseif (AllianceScore <= HordeScore) then
						BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\Horde.wav");
				end
				
				BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\InTheLead.wav");
				
				if (BGSoundAlerts_ResourcesByUpdate == 1) then
				    local Diff = 0;
				    BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\By.wav");
				    -- Work out score difference
				    if (AllianceScore > HordeScore) then
						Diff = AllianceScore - HordeScore;
				    else
						Diff = HordeScore - AllianceScore;
				    end
					-- Play score difference
					BGSoundAlerts_AddNumberToQueue(Diff);
				else                 				
					-- Here comes the important bit
					
					BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\Alliance.wav");				
					
					-- Play the Alliance score
					BGSoundAlerts_AddNumberToQueue(AllianceScore);
					
					BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\Resources.wav");
					BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\And.wav");
					BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\Horde.wav");
					
					-- Play the Horde score
					BGSoundAlerts_AddNumberToQueue(HordeScore);
			    end
				
				BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\Resources.wav");
			end
			this.TimeSinceLastUpdate = this.TimeSinceLastUpdate - ABScoreDelay * 60;
		end
	else
		-- We're not in AB so reset the timers
		this.TimeSinceLastUpdate = 0;
		BGSoundAlerts_ABGameTime = 0;
	end
end

function BGSoundAlerts_UpdateEOTSScore(elapsed)
	if (GetRealZoneText() == "Eye of the Storm" and EOTSScore == 1) then
		if (not WorldMapFrame:IsVisible()) then
			-- It appears there's a problem when the World Map is open
			this.TimeSinceLastUpdate = this.TimeSinceLastUpdate + elapsed;
		end
		while (this.TimeSinceLastUpdate > EOTSScoreDelay * 60) do
			BGSoundAlerts_EOTSGameTime = BGSoundAlerts_EOTSGameTime + EOTSScoreDelay;
			if (SoundsPack == "DefaultPack") then
				-- Work out the BG elapsed time
				BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\After.wav");
				BGSoundAlerts_AddNumberToQueue(BGSoundAlerts_EOTSGameTime);
				BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\MinutesEyeOfTheStorm.wav");
				
				local AllianceScore = AlwaysUpFrame1Text:GetText();
				local HordeScore = AlwaysUpFrame2Text:GetText();
				
				AllianceScore = tonumber(string.sub(AllianceScore,27,string.find(AllianceScore,"/") - 1));
				HordeScore = tonumber(string.sub(HordeScore,27,string.find(HordeScore,"/") - 1));
				
				-- See who's in the lead
				if (AllianceScore > HordeScore) then
						BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\Alliance.wav");
				elseif (AllianceScore <= HordeScore) then
						BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\Horde.wav");
				end
				
				BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\InTheLead.wav");
				
				if (BGSoundAlerts_ResourcesByUpdate == 1) then
				    local Diff = 0;
				    BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\By.wav");
				    -- Work out score difference
				    if (AllianceScore > HordeScore) then
						Diff = AllianceScore - HordeScore;
				    else
						Diff = HordeScore - AllianceScore;
				    end
					-- Play the score difference
					BGSoundAlerts_AddNumberToQueue(Diff);
					BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\Points.wav");
				else					
					-- Here comes the important bit
					BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\Alliance.wav");				
					
					-- Play the Alliance score
					BGSoundAlerts_AddNumberToQueue(AllianceScore);
					
					BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\Points.wav");
					BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\And.wav");
					BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\Horde.wav");
					
					-- Play the Horde score
					BGSoundAlerts_AddNumberToQueue(HordeScore);
					
					BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\Points.wav");
				end
			end
			this.TimeSinceLastUpdate = this.TimeSinceLastUpdate - ABScoreDelay * 60;
		end
	else
		-- We're not in EOTS so reset timers
		this.TimeSinceLastUpdate = 0;
		BGSoundAlerts_EOTSGameTime = 0;
	end
end

function BGSoundAlerts_ApplyKillBonus(killmsg)
	
	if (MultiKillSounds == 1) then
		if (GetRealZoneText() == "Alterac Valley") or (GetRealZoneText() == "Warsong Gulch")
			or (GetRealZoneText() == "Arathi Basin") or (GetRealZoneText() == "Eye of the Storm") then
				if (string.find(killmsg,"You have slain") ~= nil) then
					if not (string.find(killmsg,"Chicken") or string.find(killmsg,"Rat") or (string.find(killmsg,				"Stormpike") and not string.find(killmsg,"Vanndar")) or string.find(killmsg,"Frostwolf")
					or string.find(killmsg,"Alterac Ram")) then
						RequestBattlefieldScoreData();
						local x;
						local numSlain = 0;
						for x = 1, GetNumBattlefieldScores() do
							local _, slain = GetBattlefieldScore(x);
							if (slain >= 1) then
								numSlain = numSlain + 1;
							end
						end
						if (numSlain == 1) then
							-- Player has dealt the first kill blow in match so play First Blood
							BGSoundAlerts_AddToQueue("Interface\\Addons\\BGSoundAlerts\\" .. SoundsPack .. "\\FirstBlood.wav");
						end
						-- Player slain something in BGs
						-- Reset KillBonus timer and play a kill bonus sound
						this.TimeSinceLastUpdate = 0;
						KillSpree_Kills = KillSpree_Kills + 1;
						if (KillSpree_Kills > MAX_NUMBER_OF_KILLS) then
							KillSpree_Kills = MAX_NUMBER_OF_KILLS;
						end
						BGSoundAlerts_AddToQueue("Interface\\Addons\\BGSoundAlerts\\" .. SoundsPack .. "\\" .. 						KillSpree_Kills .. "Kill.wav");
					else
						return;
					end
				end
			end
		end
end

function BGSoundAlerts_UpdateKillBonus(elapsed)
	this.TimeSinceLastUpdate = this.TimeSinceLastUpdate + elapsed; 	
	while (this.TimeSinceLastUpdate > BGSoundAlerts_NextKillUpdate) do
	    this.TimeSinceLastUpdate = this.TimeSinceLastUpdate - BGSoundAlerts_NextKillUpdate;
		-- Reset Kills
		KillSpree_Kills = 0;
	end
end
